from {{cookiecutter.package_name}} import problem
from {{cookiecutter.package_name}} import datastream
from {{cookiecutter.package_name}} import architecture

from {{cookiecutter.package_name}}.train import train
